# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.8
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.





from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_CGAL_AABB_tree', [dirname(__file__)])
        except ImportError:
            import _CGAL_AABB_tree
            return _CGAL_AABB_tree
        if fp is not None:
            try:
                _mod = imp.load_module('_CGAL_AABB_tree', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _CGAL_AABB_tree = swig_import_helper()
    del swig_import_helper
else:
    import _CGAL_AABB_tree
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


import CGAL.CGAL_Kernel
import CGAL.CGAL_Polyhedron_3
class Object(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Object, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Object, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_AABB_tree.new_Object()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def is_Point_2(self):
        return _CGAL_AABB_tree.Object_is_Point_2(self)

    def get_Point_2(self):
        return _CGAL_AABB_tree.Object_get_Point_2(self)

    def is_Point_3(self):
        return _CGAL_AABB_tree.Object_is_Point_3(self)

    def get_Point_3(self):
        return _CGAL_AABB_tree.Object_get_Point_3(self)

    def is_Triangle_2(self):
        return _CGAL_AABB_tree.Object_is_Triangle_2(self)

    def get_Triangle_2(self):
        return _CGAL_AABB_tree.Object_get_Triangle_2(self)

    def is_Triangle_3(self):
        return _CGAL_AABB_tree.Object_is_Triangle_3(self)

    def get_Triangle_3(self):
        return _CGAL_AABB_tree.Object_get_Triangle_3(self)

    def is_Segment_3(self):
        return _CGAL_AABB_tree.Object_is_Segment_3(self)

    def get_Segment_3(self):
        return _CGAL_AABB_tree.Object_get_Segment_3(self)

    def is_Segment_2(self):
        return _CGAL_AABB_tree.Object_is_Segment_2(self)

    def get_Segment_2(self):
        return _CGAL_AABB_tree.Object_get_Segment_2(self)

    def is_Line_3(self):
        return _CGAL_AABB_tree.Object_is_Line_3(self)

    def get_Line_3(self):
        return _CGAL_AABB_tree.Object_get_Line_3(self)

    def is_Line_2(self):
        return _CGAL_AABB_tree.Object_is_Line_2(self)

    def get_Line_2(self):
        return _CGAL_AABB_tree.Object_get_Line_2(self)

    def is_Plane_3(self):
        return _CGAL_AABB_tree.Object_is_Plane_3(self)

    def get_Plane_3(self):
        return _CGAL_AABB_tree.Object_get_Plane_3(self)

    def is_Ray_2(self):
        return _CGAL_AABB_tree.Object_is_Ray_2(self)

    def get_Ray_2(self):
        return _CGAL_AABB_tree.Object_get_Ray_2(self)

    def is_Ray_3(self):
        return _CGAL_AABB_tree.Object_is_Ray_3(self)

    def get_Ray_3(self):
        return _CGAL_AABB_tree.Object_get_Ray_3(self)

    def empty(self):
        return _CGAL_AABB_tree.Object_empty(self)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Object
    __del__ = lambda self: None
Object_swigregister = _CGAL_AABB_tree.Object_swigregister
Object_swigregister(Object)

class Point_and_Polyhedron_3_Facet_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Point_and_Polyhedron_3_Facet_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Point_and_Polyhedron_3_Facet_handle, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_AABB_tree.new_Point_and_Polyhedron_3_Facet_handle(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_first_set
    __swig_getmethods__["first"] = _CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_first_get
    if _newclass:
        first = _swig_property(_CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_first_get, _CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_first_set)
    __swig_setmethods__["second"] = _CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_second_set
    __swig_getmethods__["second"] = _CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_second_get
    if _newclass:
        second = _swig_property(_CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_second_get, _CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Point_and_Polyhedron_3_Facet_handle
    __del__ = lambda self: None
Point_and_Polyhedron_3_Facet_handle_swigregister = _CGAL_AABB_tree.Point_and_Polyhedron_3_Facet_handle_swigregister
Point_and_Polyhedron_3_Facet_handle_swigregister(Point_and_Polyhedron_3_Facet_handle)

class Point_and_Polyhedron_3_Halfedge_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Point_and_Polyhedron_3_Halfedge_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Point_and_Polyhedron_3_Halfedge_handle, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_AABB_tree.new_Point_and_Polyhedron_3_Halfedge_handle(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_first_set
    __swig_getmethods__["first"] = _CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_first_get
    if _newclass:
        first = _swig_property(_CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_first_get, _CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_first_set)
    __swig_setmethods__["second"] = _CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_second_set
    __swig_getmethods__["second"] = _CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_second_get
    if _newclass:
        second = _swig_property(_CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_second_get, _CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Point_and_Polyhedron_3_Halfedge_handle
    __del__ = lambda self: None
Point_and_Polyhedron_3_Halfedge_handle_swigregister = _CGAL_AABB_tree.Point_and_Polyhedron_3_Halfedge_handle_swigregister
Point_and_Polyhedron_3_Halfedge_handle_swigregister(Point_and_Polyhedron_3_Halfedge_handle)

class Point_and_Integer(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Point_and_Integer, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Point_and_Integer, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_AABB_tree.new_Point_and_Integer(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_AABB_tree.Point_and_Integer_first_set
    __swig_getmethods__["first"] = _CGAL_AABB_tree.Point_and_Integer_first_get
    if _newclass:
        first = _swig_property(_CGAL_AABB_tree.Point_and_Integer_first_get, _CGAL_AABB_tree.Point_and_Integer_first_set)
    __swig_setmethods__["second"] = _CGAL_AABB_tree.Point_and_Integer_second_set
    __swig_getmethods__["second"] = _CGAL_AABB_tree.Point_and_Integer_second_get
    if _newclass:
        second = _swig_property(_CGAL_AABB_tree.Point_and_Integer_second_get, _CGAL_AABB_tree.Point_and_Integer_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Point_and_Integer
    __del__ = lambda self: None
Point_and_Integer_swigregister = _CGAL_AABB_tree.Point_and_Integer_swigregister
Point_and_Integer_swigregister(Point_and_Integer)

class Object_and_Polyhedron_3_Facet_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Object_and_Polyhedron_3_Facet_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Object_and_Polyhedron_3_Facet_handle, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_AABB_tree.new_Object_and_Polyhedron_3_Facet_handle(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_first_set
    __swig_getmethods__["first"] = _CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_first_get
    if _newclass:
        first = _swig_property(_CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_first_get, _CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_first_set)
    __swig_setmethods__["second"] = _CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_second_set
    __swig_getmethods__["second"] = _CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_second_get
    if _newclass:
        second = _swig_property(_CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_second_get, _CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Object_and_Polyhedron_3_Facet_handle
    __del__ = lambda self: None
Object_and_Polyhedron_3_Facet_handle_swigregister = _CGAL_AABB_tree.Object_and_Polyhedron_3_Facet_handle_swigregister
Object_and_Polyhedron_3_Facet_handle_swigregister(Object_and_Polyhedron_3_Facet_handle)

class Object_and_Polyhedron_3_Halfedge_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Object_and_Polyhedron_3_Halfedge_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Object_and_Polyhedron_3_Halfedge_handle, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_AABB_tree.new_Object_and_Polyhedron_3_Halfedge_handle(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_first_set
    __swig_getmethods__["first"] = _CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_first_get
    if _newclass:
        first = _swig_property(_CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_first_get, _CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_first_set)
    __swig_setmethods__["second"] = _CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_second_set
    __swig_getmethods__["second"] = _CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_second_get
    if _newclass:
        second = _swig_property(_CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_second_get, _CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Object_and_Polyhedron_3_Halfedge_handle
    __del__ = lambda self: None
Object_and_Polyhedron_3_Halfedge_handle_swigregister = _CGAL_AABB_tree.Object_and_Polyhedron_3_Halfedge_handle_swigregister
Object_and_Polyhedron_3_Halfedge_handle_swigregister(Object_and_Polyhedron_3_Halfedge_handle)

class Object_and_Integer(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Object_and_Integer, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Object_and_Integer, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_AABB_tree.new_Object_and_Integer(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_AABB_tree.Object_and_Integer_first_set
    __swig_getmethods__["first"] = _CGAL_AABB_tree.Object_and_Integer_first_get
    if _newclass:
        first = _swig_property(_CGAL_AABB_tree.Object_and_Integer_first_get, _CGAL_AABB_tree.Object_and_Integer_first_set)
    __swig_setmethods__["second"] = _CGAL_AABB_tree.Object_and_Integer_second_set
    __swig_getmethods__["second"] = _CGAL_AABB_tree.Object_and_Integer_second_get
    if _newclass:
        second = _swig_property(_CGAL_AABB_tree.Object_and_Integer_second_get, _CGAL_AABB_tree.Object_and_Integer_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_AABB_tree.delete_Object_and_Integer
    __del__ = lambda self: None
Object_and_Integer_swigregister = _CGAL_AABB_tree.Object_and_Integer_swigregister
Object_and_Integer_swigregister(Object_and_Integer)

class Optional_Polyhedron_3_Halfedge_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Optional_Polyhedron_3_Halfedge_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Optional_Polyhedron_3_Halfedge_handle, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_AABB_tree.new_Optional_Polyhedron_3_Halfedge_handle()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def empty(self):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Halfedge_handle_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Halfedge_handle_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Halfedge_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Polyhedron_3_Halfedge_handle
    __del__ = lambda self: None
Optional_Polyhedron_3_Halfedge_handle_swigregister = _CGAL_AABB_tree.Optional_Polyhedron_3_Halfedge_handle_swigregister
Optional_Polyhedron_3_Halfedge_handle_swigregister(Optional_Polyhedron_3_Halfedge_handle)

class Optional_Polyhedron_3_Facet_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Optional_Polyhedron_3_Facet_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Optional_Polyhedron_3_Facet_handle, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_AABB_tree.new_Optional_Polyhedron_3_Facet_handle()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def empty(self):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Facet_handle_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Facet_handle_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Polyhedron_3_Facet_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Polyhedron_3_Facet_handle
    __del__ = lambda self: None
Optional_Polyhedron_3_Facet_handle_swigregister = _CGAL_AABB_tree.Optional_Polyhedron_3_Facet_handle_swigregister
Optional_Polyhedron_3_Facet_handle_swigregister(Optional_Polyhedron_3_Facet_handle)

class Optional_Integer(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Optional_Integer, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Optional_Integer, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_AABB_tree.new_Optional_Integer()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def empty(self):
        return _CGAL_AABB_tree.Optional_Integer_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Integer_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Integer_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Integer
    __del__ = lambda self: None
Optional_Integer_swigregister = _CGAL_AABB_tree.Optional_Integer_swigregister
Optional_Integer_swigregister(Optional_Integer)

class Optional_Object_and_Polyhedron_3_Halfedge_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Optional_Object_and_Polyhedron_3_Halfedge_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Optional_Object_and_Polyhedron_3_Halfedge_handle, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_AABB_tree.new_Optional_Object_and_Polyhedron_3_Halfedge_handle()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def empty(self):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Halfedge_handle_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Halfedge_handle_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Halfedge_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Object_and_Polyhedron_3_Halfedge_handle
    __del__ = lambda self: None
Optional_Object_and_Polyhedron_3_Halfedge_handle_swigregister = _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Halfedge_handle_swigregister
Optional_Object_and_Polyhedron_3_Halfedge_handle_swigregister(Optional_Object_and_Polyhedron_3_Halfedge_handle)

class Optional_Object_and_Polyhedron_3_Facet_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Optional_Object_and_Polyhedron_3_Facet_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Optional_Object_and_Polyhedron_3_Facet_handle, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_AABB_tree.new_Optional_Object_and_Polyhedron_3_Facet_handle()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def empty(self):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Facet_handle_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Facet_handle_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Facet_handle_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Object_and_Polyhedron_3_Facet_handle
    __del__ = lambda self: None
Optional_Object_and_Polyhedron_3_Facet_handle_swigregister = _CGAL_AABB_tree.Optional_Object_and_Polyhedron_3_Facet_handle_swigregister
Optional_Object_and_Polyhedron_3_Facet_handle_swigregister(Optional_Object_and_Polyhedron_3_Facet_handle)

class Optional_Object_and_Integer(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Optional_Object_and_Integer, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Optional_Object_and_Integer, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_AABB_tree.new_Optional_Object_and_Integer()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def empty(self):
        return _CGAL_AABB_tree.Optional_Object_and_Integer_empty(self)

    def value(self):
        return _CGAL_AABB_tree.Optional_Object_and_Integer_value(self)

    def deepcopy(self, *args):
        return _CGAL_AABB_tree.Optional_Object_and_Integer_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_Optional_Object_and_Integer
    __del__ = lambda self: None
Optional_Object_and_Integer_swigregister = _CGAL_AABB_tree.Optional_Object_and_Integer_swigregister
Optional_Object_and_Integer_swigregister(Optional_Object_and_Integer)

class AABB_tree_Polyhedron_3_Facet_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, AABB_tree_Polyhedron_3_Facet_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, AABB_tree_Polyhedron_3_Facet_handle, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_AABB_tree.new_AABB_tree_Polyhedron_3_Facet_handle(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def rebuild(self, range):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_rebuild(self, range)

    def clear(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_clear(self)

    def size(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_size(self)

    def empty(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_empty(self)

    def do_intersect(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_do_intersect(self, *args)

    def number_of_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_number_of_intersected_primitives(self, *args)

    def all_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_all_intersected_primitives(self, *args)

    def any_intersected_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_any_intersected_primitive(self, *args)

    def any_intersection(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_any_intersection(self, *args)

    def all_intersections(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_all_intersections(self, *args)

    def squared_distance(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_squared_distance(self, *args)

    def closest_point(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_closest_point(self, *args)

    def closest_point_and_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_closest_point_and_primitive(self, *args)

    def accelerate_distance_queries(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_accelerate_distance_queries(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_AABB_tree_Polyhedron_3_Facet_handle
    __del__ = lambda self: None
AABB_tree_Polyhedron_3_Facet_handle_swigregister = _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Facet_handle_swigregister
AABB_tree_Polyhedron_3_Facet_handle_swigregister(AABB_tree_Polyhedron_3_Facet_handle)

class AABB_tree_Polyhedron_3_Halfedge_handle(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, AABB_tree_Polyhedron_3_Halfedge_handle, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, AABB_tree_Polyhedron_3_Halfedge_handle, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_AABB_tree.new_AABB_tree_Polyhedron_3_Halfedge_handle(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def rebuild(self, range):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_rebuild(self, range)

    def clear(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_clear(self)

    def size(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_size(self)

    def empty(self):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_empty(self)

    def do_intersect(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_do_intersect(self, *args)

    def number_of_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_number_of_intersected_primitives(self, *args)

    def all_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_all_intersected_primitives(self, *args)

    def any_intersected_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_any_intersected_primitive(self, *args)

    def any_intersection(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_any_intersection(self, *args)

    def all_intersections(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_all_intersections(self, *args)

    def squared_distance(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_squared_distance(self, *args)

    def closest_point(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_closest_point(self, *args)

    def closest_point_and_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_closest_point_and_primitive(self, *args)

    def accelerate_distance_queries(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_accelerate_distance_queries(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_AABB_tree_Polyhedron_3_Halfedge_handle
    __del__ = lambda self: None
AABB_tree_Polyhedron_3_Halfedge_handle_swigregister = _CGAL_AABB_tree.AABB_tree_Polyhedron_3_Halfedge_handle_swigregister
AABB_tree_Polyhedron_3_Halfedge_handle_swigregister(AABB_tree_Polyhedron_3_Halfedge_handle)

class AABB_tree_Segment_3_soup(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, AABB_tree_Segment_3_soup, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, AABB_tree_Segment_3_soup, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_AABB_tree.new_AABB_tree_Segment_3_soup(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert_from_array(self, input):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_insert_from_array(self, input)

    def rebuild(self, range):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_rebuild(self, range)

    def clear(self):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_clear(self)

    def size(self):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_size(self)

    def empty(self):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_empty(self)

    def do_intersect(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_do_intersect(self, *args)

    def number_of_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_number_of_intersected_primitives(self, *args)

    def all_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_all_intersected_primitives(self, *args)

    def any_intersected_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_any_intersected_primitive(self, *args)

    def any_intersection(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_any_intersection(self, *args)

    def all_intersections(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_all_intersections(self, *args)

    def squared_distance(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_squared_distance(self, *args)

    def closest_point(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_closest_point(self, *args)

    def closest_point_and_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_closest_point_and_primitive(self, *args)

    def accelerate_distance_queries(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Segment_3_soup_accelerate_distance_queries(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_AABB_tree_Segment_3_soup
    __del__ = lambda self: None
AABB_tree_Segment_3_soup_swigregister = _CGAL_AABB_tree.AABB_tree_Segment_3_soup_swigregister
AABB_tree_Segment_3_soup_swigregister(AABB_tree_Segment_3_soup)

class AABB_tree_Triangle_3_soup(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, AABB_tree_Triangle_3_soup, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, AABB_tree_Triangle_3_soup, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_AABB_tree.new_AABB_tree_Triangle_3_soup(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def insert_from_array(self, input):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_insert_from_array(self, input)

    def rebuild(self, range):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_rebuild(self, range)

    def clear(self):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_clear(self)

    def size(self):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_size(self)

    def empty(self):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_empty(self)

    def do_intersect(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_do_intersect(self, *args)

    def number_of_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_number_of_intersected_primitives(self, *args)

    def all_intersected_primitives(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_all_intersected_primitives(self, *args)

    def any_intersected_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_any_intersected_primitive(self, *args)

    def any_intersection(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_any_intersection(self, *args)

    def all_intersections(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_all_intersections(self, *args)

    def squared_distance(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_squared_distance(self, *args)

    def closest_point(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_closest_point(self, *args)

    def closest_point_and_primitive(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_closest_point_and_primitive(self, *args)

    def accelerate_distance_queries(self, *args):
        return _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_accelerate_distance_queries(self, *args)
    __swig_destroy__ = _CGAL_AABB_tree.delete_AABB_tree_Triangle_3_soup
    __del__ = lambda self: None
AABB_tree_Triangle_3_soup_swigregister = _CGAL_AABB_tree.AABB_tree_Triangle_3_soup_swigregister
AABB_tree_Triangle_3_soup_swigregister(AABB_tree_Triangle_3_soup)

# This file is compatible with both classic and new-style classes.





# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.8
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.





from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_CGAL_Box_intersection_d', [dirname(__file__)])
        except ImportError:
            import _CGAL_Box_intersection_d
            return _CGAL_Box_intersection_d
        if fp is not None:
            try:
                _mod = imp.load_module('_CGAL_Box_intersection_d', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _CGAL_Box_intersection_d = swig_import_helper()
    del swig_import_helper
else:
    import _CGAL_Box_intersection_d
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


import CGAL.CGAL_Kernel
class Pair_of_int(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Pair_of_int, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Pair_of_int, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Box_intersection_d.new_Pair_of_int(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_Box_intersection_d.Pair_of_int_first_set
    __swig_getmethods__["first"] = _CGAL_Box_intersection_d.Pair_of_int_first_get
    if _newclass:
        first = _swig_property(_CGAL_Box_intersection_d.Pair_of_int_first_get, _CGAL_Box_intersection_d.Pair_of_int_first_set)
    __swig_setmethods__["second"] = _CGAL_Box_intersection_d.Pair_of_int_second_set
    __swig_getmethods__["second"] = _CGAL_Box_intersection_d.Pair_of_int_second_get
    if _newclass:
        second = _swig_property(_CGAL_Box_intersection_d.Pair_of_int_second_get, _CGAL_Box_intersection_d.Pair_of_int_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Box_intersection_d.delete_Pair_of_int
    __del__ = lambda self: None
Pair_of_int_swigregister = _CGAL_Box_intersection_d.Pair_of_int_swigregister
Pair_of_int_swigregister(Pair_of_int)

class Ids_iterator(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Ids_iterator, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Ids_iterator, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Box_intersection_d.new_Ids_iterator()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __iter__(self):
        return _CGAL_Box_intersection_d.Ids_iterator___iter__(self)

    def __next__(self):
        return _CGAL_Box_intersection_d.Ids_iterator___next__(self)

    def next(self, *args):
        return _CGAL_Box_intersection_d.Ids_iterator_next(self, *args)

    def deepcopy(self, *args):
        return _CGAL_Box_intersection_d.Ids_iterator_deepcopy(self, *args)

    def hasNext(self):
        return _CGAL_Box_intersection_d.Ids_iterator_hasNext(self)

    def __eq__(self, p):
        return _CGAL_Box_intersection_d.Ids_iterator___eq__(self, p)

    def __ne__(self, p):
        return _CGAL_Box_intersection_d.Ids_iterator___ne__(self, p)
    __swig_destroy__ = _CGAL_Box_intersection_d.delete_Ids_iterator
    __del__ = lambda self: None
Ids_iterator_swigregister = _CGAL_Box_intersection_d.Ids_iterator_swigregister
Ids_iterator_swigregister(Ids_iterator)

class Box_for_segment_polyline_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Box_for_segment_polyline_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Box_for_segment_polyline_2, name)
    __repr__ = _swig_repr

    def __init__(self, s, polyline_id, id):
        this = _CGAL_Box_intersection_d.new_Box_for_segment_polyline_2(s, polyline_id, id)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_destroy__ = _CGAL_Box_intersection_d.delete_Box_for_segment_polyline_2
    __del__ = lambda self: None
Box_for_segment_polyline_2_swigregister = _CGAL_Box_intersection_d.Box_for_segment_polyline_2_swigregister
Box_for_segment_polyline_2_swigregister(Box_for_segment_polyline_2)

class Box_with_id_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Box_with_id_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Box_with_id_2, name)
    __repr__ = _swig_repr

    def __init__(self, bbox, id):
        this = _CGAL_Box_intersection_d.new_Box_with_id_2(bbox, id)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_destroy__ = _CGAL_Box_intersection_d.delete_Box_with_id_2
    __del__ = lambda self: None
Box_with_id_2_swigregister = _CGAL_Box_intersection_d.Box_with_id_2_swigregister
Box_with_id_2_swigregister(Box_with_id_2)

class Box_with_id_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Box_with_id_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Box_with_id_3, name)
    __repr__ = _swig_repr

    def __init__(self, bbox, id):
        this = _CGAL_Box_intersection_d.new_Box_with_id_3(bbox, id)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_destroy__ = _CGAL_Box_intersection_d.delete_Box_with_id_3
    __del__ = lambda self: None
Box_with_id_3_swigregister = _CGAL_Box_intersection_d.Box_with_id_3_swigregister
Box_with_id_3_swigregister(Box_with_id_3)


_CGAL_Box_intersection_d.COMPLETE_swigconstant(_CGAL_Box_intersection_d)
COMPLETE = _CGAL_Box_intersection_d.COMPLETE

_CGAL_Box_intersection_d.BIPARTITE_swigconstant(_CGAL_Box_intersection_d)
BIPARTITE = _CGAL_Box_intersection_d.BIPARTITE

_CGAL_Box_intersection_d.HALF_OPEN_swigconstant(_CGAL_Box_intersection_d)
HALF_OPEN = _CGAL_Box_intersection_d.HALF_OPEN

_CGAL_Box_intersection_d.CLOSED_swigconstant(_CGAL_Box_intersection_d)
CLOSED = _CGAL_Box_intersection_d.CLOSED
class Collect_ids_callback_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Collect_ids_callback_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Collect_ids_callback_2, name)
    __repr__ = _swig_repr

    def ids(self):
        return _CGAL_Box_intersection_d.Collect_ids_callback_2_ids(self)

    def __init__(self):
        this = _CGAL_Box_intersection_d.new_Collect_ids_callback_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_destroy__ = _CGAL_Box_intersection_d.delete_Collect_ids_callback_2
    __del__ = lambda self: None
Collect_ids_callback_2_swigregister = _CGAL_Box_intersection_d.Collect_ids_callback_2_swigregister
Collect_ids_callback_2_swigregister(Collect_ids_callback_2)

class Collect_ids_callback_3(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Collect_ids_callback_3, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Collect_ids_callback_3, name)
    __repr__ = _swig_repr

    def ids(self):
        return _CGAL_Box_intersection_d.Collect_ids_callback_3_ids(self)

    def __init__(self):
        this = _CGAL_Box_intersection_d.new_Collect_ids_callback_3()
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_destroy__ = _CGAL_Box_intersection_d.delete_Collect_ids_callback_3
    __del__ = lambda self: None
Collect_ids_callback_3_swigregister = _CGAL_Box_intersection_d.Collect_ids_callback_3_swigregister
Collect_ids_callback_3_swigregister(Collect_ids_callback_3)


def box_intersection_d(*args):
    return _CGAL_Box_intersection_d.box_intersection_d(*args)
box_intersection_d = _CGAL_Box_intersection_d.box_intersection_d

def box_intersection_all_pairs_d(*args):
    return _CGAL_Box_intersection_d.box_intersection_all_pairs_d(*args)
box_intersection_all_pairs_d = _CGAL_Box_intersection_d.box_intersection_all_pairs_d

def box_self_intersection_d(*args):
    return _CGAL_Box_intersection_d.box_self_intersection_d(*args)
box_self_intersection_d = _CGAL_Box_intersection_d.box_self_intersection_d

def box_self_intersection_all_pairs_d(*args):
    return _CGAL_Box_intersection_d.box_self_intersection_all_pairs_d(*args)
box_self_intersection_all_pairs_d = _CGAL_Box_intersection_d.box_self_intersection_all_pairs_d
# This file is compatible with both classic and new-style classes.





# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.8
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.





from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_CGAL_Interpolation', [dirname(__file__)])
        except ImportError:
            import _CGAL_Interpolation
            return _CGAL_Interpolation
        if fp is not None:
            try:
                _mod = imp.load_module('_CGAL_Interpolation', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _CGAL_Interpolation = swig_import_helper()
    del swig_import_helper
else:
    import _CGAL_Interpolation
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


import CGAL.CGAL_Triangulation_2
import CGAL.CGAL_Kernel
import CGAL.CGAL_Triangulation_3
class Double_and_bool(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Double_and_bool, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Double_and_bool, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Interpolation.new_Double_and_bool(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_Interpolation.Double_and_bool_first_set
    __swig_getmethods__["first"] = _CGAL_Interpolation.Double_and_bool_first_get
    if _newclass:
        first = _swig_property(_CGAL_Interpolation.Double_and_bool_first_get, _CGAL_Interpolation.Double_and_bool_first_set)
    __swig_setmethods__["second"] = _CGAL_Interpolation.Double_and_bool_second_set
    __swig_getmethods__["second"] = _CGAL_Interpolation.Double_and_bool_second_get
    if _newclass:
        second = _swig_property(_CGAL_Interpolation.Double_and_bool_second_get, _CGAL_Interpolation.Double_and_bool_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Interpolation.delete_Double_and_bool
    __del__ = lambda self: None
Double_and_bool_swigregister = _CGAL_Interpolation.Double_and_bool_swigregister
Double_and_bool_swigregister(Double_and_bool)

class Double_bool_bool(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Double_bool_bool, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Double_bool_bool, name)
    __repr__ = _swig_repr
    __swig_setmethods__["first"] = _CGAL_Interpolation.Double_bool_bool_first_set
    __swig_getmethods__["first"] = _CGAL_Interpolation.Double_bool_bool_first_get
    if _newclass:
        first = _swig_property(_CGAL_Interpolation.Double_bool_bool_first_get, _CGAL_Interpolation.Double_bool_bool_first_set)
    __swig_setmethods__["second"] = _CGAL_Interpolation.Double_bool_bool_second_set
    __swig_getmethods__["second"] = _CGAL_Interpolation.Double_bool_bool_second_get
    if _newclass:
        second = _swig_property(_CGAL_Interpolation.Double_bool_bool_second_get, _CGAL_Interpolation.Double_bool_bool_second_set)
    __swig_setmethods__["third"] = _CGAL_Interpolation.Double_bool_bool_third_set
    __swig_getmethods__["third"] = _CGAL_Interpolation.Double_bool_bool_third_get
    if _newclass:
        third = _swig_property(_CGAL_Interpolation.Double_bool_bool_third_get, _CGAL_Interpolation.Double_bool_bool_third_set)

    def __init__(self, *args):
        this = _CGAL_Interpolation.new_Double_bool_bool(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def deepcopy(self, *args):
        return _CGAL_Interpolation.Double_bool_bool_deepcopy(self, *args)
    __swig_destroy__ = _CGAL_Interpolation.delete_Double_bool_bool
    __del__ = lambda self: None
Double_bool_bool_swigregister = _CGAL_Interpolation.Double_bool_bool_swigregister
Double_bool_bool_swigregister(Double_bool_bool)

class Point_2_and_double(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Point_2_and_double, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Point_2_and_double, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Interpolation.new_Point_2_and_double(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_Interpolation.Point_2_and_double_first_set
    __swig_getmethods__["first"] = _CGAL_Interpolation.Point_2_and_double_first_get
    if _newclass:
        first = _swig_property(_CGAL_Interpolation.Point_2_and_double_first_get, _CGAL_Interpolation.Point_2_and_double_first_set)
    __swig_setmethods__["second"] = _CGAL_Interpolation.Point_2_and_double_second_set
    __swig_getmethods__["second"] = _CGAL_Interpolation.Point_2_and_double_second_get
    if _newclass:
        second = _swig_property(_CGAL_Interpolation.Point_2_and_double_second_get, _CGAL_Interpolation.Point_2_and_double_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Interpolation.delete_Point_2_and_double
    __del__ = lambda self: None
Point_2_and_double_swigregister = _CGAL_Interpolation.Point_2_and_double_swigregister
Point_2_and_double_swigregister(Point_2_and_double)

class Weighted_point_2_and_double(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Weighted_point_2_and_double, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Weighted_point_2_and_double, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Interpolation.new_Weighted_point_2_and_double(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_Interpolation.Weighted_point_2_and_double_first_set
    __swig_getmethods__["first"] = _CGAL_Interpolation.Weighted_point_2_and_double_first_get
    if _newclass:
        first = _swig_property(_CGAL_Interpolation.Weighted_point_2_and_double_first_get, _CGAL_Interpolation.Weighted_point_2_and_double_first_set)
    __swig_setmethods__["second"] = _CGAL_Interpolation.Weighted_point_2_and_double_second_set
    __swig_getmethods__["second"] = _CGAL_Interpolation.Weighted_point_2_and_double_second_get
    if _newclass:
        second = _swig_property(_CGAL_Interpolation.Weighted_point_2_and_double_second_get, _CGAL_Interpolation.Weighted_point_2_and_double_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Interpolation.delete_Weighted_point_2_and_double
    __del__ = lambda self: None
Weighted_point_2_and_double_swigregister = _CGAL_Interpolation.Weighted_point_2_and_double_swigregister
Weighted_point_2_and_double_swigregister(Weighted_point_2_and_double)

class Point_3_and_double(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Point_3_and_double, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Point_3_and_double, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _CGAL_Interpolation.new_Point_3_and_double(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_setmethods__["first"] = _CGAL_Interpolation.Point_3_and_double_first_set
    __swig_getmethods__["first"] = _CGAL_Interpolation.Point_3_and_double_first_get
    if _newclass:
        first = _swig_property(_CGAL_Interpolation.Point_3_and_double_first_get, _CGAL_Interpolation.Point_3_and_double_first_set)
    __swig_setmethods__["second"] = _CGAL_Interpolation.Point_3_and_double_second_set
    __swig_getmethods__["second"] = _CGAL_Interpolation.Point_3_and_double_second_get
    if _newclass:
        second = _swig_property(_CGAL_Interpolation.Point_3_and_double_second_get, _CGAL_Interpolation.Point_3_and_double_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _CGAL_Interpolation.delete_Point_3_and_double
    __del__ = lambda self: None
Point_3_and_double_swigregister = _CGAL_Interpolation.Point_3_and_double_swigregister
Point_3_and_double_swigregister(Point_3_and_double)

class Data_access_double_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Data_access_double_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Data_access_double_2, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Interpolation.new_Data_access_double_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def set(self, p, value):
        return _CGAL_Interpolation.Data_access_double_2_set(self, p, value)

    def get(self, p):
        return _CGAL_Interpolation.Data_access_double_2_get(self, p)
    __swig_destroy__ = _CGAL_Interpolation.delete_Data_access_double_2
    __del__ = lambda self: None
Data_access_double_2_swigregister = _CGAL_Interpolation.Data_access_double_2_swigregister
Data_access_double_2_swigregister(Data_access_double_2)

class Data_access_vector_2(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Data_access_vector_2, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Data_access_vector_2, name)
    __repr__ = _swig_repr

    def __init__(self):
        this = _CGAL_Interpolation.new_Data_access_vector_2()
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def set(self, p, value):
        return _CGAL_Interpolation.Data_access_vector_2_set(self, p, value)

    def get(self, p):
        return _CGAL_Interpolation.Data_access_vector_2_get(self, p)
    __swig_destroy__ = _CGAL_Interpolation.delete_Data_access_vector_2
    __del__ = lambda self: None
Data_access_vector_2_swigregister = _CGAL_Interpolation.Data_access_vector_2_swigregister
Data_access_vector_2_swigregister(Data_access_vector_2)


def natural_neighbor_coordinates_2(*args):
    return _CGAL_Interpolation.natural_neighbor_coordinates_2(*args)
natural_neighbor_coordinates_2 = _CGAL_Interpolation.natural_neighbor_coordinates_2

def regular_neighbor_coordinates_2(*args):
    return _CGAL_Interpolation.regular_neighbor_coordinates_2(*args)
regular_neighbor_coordinates_2 = _CGAL_Interpolation.regular_neighbor_coordinates_2

def surface_neighbors_certified_3(*args):
    return _CGAL_Interpolation.surface_neighbors_certified_3(*args)
surface_neighbors_certified_3 = _CGAL_Interpolation.surface_neighbors_certified_3

def surface_neighbors_3(*args):
    return _CGAL_Interpolation.surface_neighbors_3(*args)
surface_neighbors_3 = _CGAL_Interpolation.surface_neighbors_3

def surface_neighbor_coordinates_certified_3(*args):
    return _CGAL_Interpolation.surface_neighbor_coordinates_certified_3(*args)
surface_neighbor_coordinates_certified_3 = _CGAL_Interpolation.surface_neighbor_coordinates_certified_3

def surface_neighbor_coordinates_3(*args):
    return _CGAL_Interpolation.surface_neighbor_coordinates_3(*args)
surface_neighbor_coordinates_3 = _CGAL_Interpolation.surface_neighbor_coordinates_3

def linear_interpolation(range, norm, function_values):
    return _CGAL_Interpolation.linear_interpolation(range, norm, function_values)
linear_interpolation = _CGAL_Interpolation.linear_interpolation

def quadratic_interpolation(range, norm, p, function_values, gradients):
    return _CGAL_Interpolation.quadratic_interpolation(range, norm, p, function_values, gradients)
quadratic_interpolation = _CGAL_Interpolation.quadratic_interpolation

def sibson_c1_interpolation(range, norm, p, function_values, gradients):
    return _CGAL_Interpolation.sibson_c1_interpolation(range, norm, p, function_values, gradients)
sibson_c1_interpolation = _CGAL_Interpolation.sibson_c1_interpolation

def sibson_c1_interpolation_square(range, norm, p, function_values, gradients):
    return _CGAL_Interpolation.sibson_c1_interpolation_square(range, norm, p, function_values, gradients)
sibson_c1_interpolation_square = _CGAL_Interpolation.sibson_c1_interpolation_square

def farin_c1_interpolation(range, norm, p, function_values, gradients):
    return _CGAL_Interpolation.farin_c1_interpolation(range, norm, p, function_values, gradients)
farin_c1_interpolation = _CGAL_Interpolation.farin_c1_interpolation

def sibson_gradient_fitting(range, norm, p, function_values):
    return _CGAL_Interpolation.sibson_gradient_fitting(range, norm, p, function_values)
sibson_gradient_fitting = _CGAL_Interpolation.sibson_gradient_fitting

def sibson_gradient_fitting_nn_2(dt, gradients, function_values):
    return _CGAL_Interpolation.sibson_gradient_fitting_nn_2(dt, gradients, function_values)
sibson_gradient_fitting_nn_2 = _CGAL_Interpolation.sibson_gradient_fitting_nn_2

def sibson_gradient_fitting_rn_2(rt, gradients, function_values):
    return _CGAL_Interpolation.sibson_gradient_fitting_rn_2(rt, gradients, function_values)
sibson_gradient_fitting_rn_2 = _CGAL_Interpolation.sibson_gradient_fitting_rn_2
# This file is compatible with both classic and new-style classes.


